@@ -413,6 +413,63 @@ g_object_info_find_method (GIObjectInfo *info,
   return _g_base_info_find_method ((GIBaseInfo*)info, offset, blob->n_methods, name);
 }
 
+/**
+ * g_object_info_find_method_using_interfaces:
+ * @info: a #GIObjectInfo
+ * @name: name of method to obtain
+ * @implementor: (out) (transfer full): The implementor of the interface
+ *
+ * Obtain a method of the object given a @name, searching both the
+ * object @info and any interfaces it implements.  %NULL will be
+ * returned if there's no method available with that name.
+ *
+ * Note that this function does *not* search parent classes; you will have
+ * to chain up if that's desired.
+ *
+ * Returns: (transfer full): the #GIFunctionInfo. Free the struct by calling
+ * g_base_info_unref() when done.
+ */
+GIFunctionInfo *
+g_object_info_find_method_using_interfaces (GIObjectInfo  *info,
+					    const gchar   *name,
+					    GIObjectInfo **implementor)
+{
+  GIFunctionInfo *result = NULL;
+  GIObjectInfo *implementor_result = NULL;
+
+  result = g_object_info_find_method (info, name);
+  if (result)
+    implementor_result = g_base_info_ref ((GIBaseInfo*) info);
+
+  if (result == NULL)
+    {
+      int n_interfaces;
+      int i;
+
+      n_interfaces = g_object_info_get_n_interfaces (info);
+      for (i = 0; i < n_interfaces; ++i)
+	{
+	  GIInterfaceInfo *iface_info;
+
+	  iface_info = g_object_info_get_interface (info, i);
+
+	  result = g_interface_info_find_method (iface_info, name);
+
+	  if (result != NULL)
+	    {
+	      implementor_result = iface_info;
+	      break;
+	    }
+	  g_base_info_unref ((GIBaseInfo*) iface_info);
+	}
+    }
+  if (implementor)
+    *implementor = implementor_result;
+  else if (implementor_result != NULL)
+    g_base_info_unref ((GIBaseInfo*) implementor_result);
+  return result;
+}
+
 /**
  * g_object_info_get_n_signals:
  * @info: a #GIObjectInfo
@@ -471,6 +528,37 @@ g_object_info_get_signal (GIObjectInfo *info,
 				      rinfo->typelib, offset);
 }
 
+/**
+ * g_object_info_find_signal:
+ * @info: a #GIObjectInfo
+ * @name: Name of signal
+ *
+ * Returns: Info for the signal with name @name in @info, or %NULL on failure.
+ */
+GISignalInfo *
+g_object_info_find_signal (GIObjectInfo *info,
+			   const gchar  *name)
+{
+  gint n_signals;
+  gint i;
+
+  n_signals = g_object_info_get_n_signals (info);
+  for (i = 0; i < n_signals; i++)
+    {
+      GISignalInfo *siginfo = g_object_info_get_signal (info, i);
+
+      if (g_strcmp0 (g_base_info_get_name (siginfo), name) != 0)
+	{
+	  g_base_info_unref ((GIBaseInfo*)siginfo);
+	  continue;
+	}
+
+      return siginfo;
+    }
+  return NULL;
+}
+
+
 /**
  * g_object_info_get_n_vfuncs:
  * @info: a #GIObjectInfo
@@ -721,7 +809,7 @@ g_object_info_get_ref_function (GIObjectInfo *info)
 }
 
 /**
- * g_object_info_get_ref_function_pointer:
+ * g_object_info_get_ref_function_pointer: (skip)
  * @info: a #GIObjectInfo
  *
  * Obtain a pointer to a function which can be used to
@@ -769,7 +857,7 @@ g_object_info_get_unref_function (GIObjectInfo *info)
 }
 
 /**
- * g_object_info_get_unref_function_pointer:
+ * g_object_info_get_unref_function_pointer: (skip)
  * @info: a #GIObjectInfo
  *
  * Obtain a pointer to a function which can be used to
@@ -818,7 +906,7 @@ g_object_info_get_set_value_function (GIObjectInfo *info)
 }
 
 /**
- * g_object_info_get_set_value_function_pointer:
+ * g_object_info_get_set_value_function_pointer: (skip)
  * @info: a #GIObjectInfo
  *
  * Obtain a pointer to a function which can be used to
@@ -867,7 +955,7 @@ g_object_info_get_get_value_function (GIObjectInfo *info)
 }
 
 /**
- * g_object_info_get_get_value_function_pointer:
+ * g_object_info_get_get_value_function_pointer: (skip)
  * @info: a #GIObjectInfo
  *
  * Obtain a pointer to a function which can be used to
