@@ -56,6 +56,14 @@ def get_preprocessor_option_group(parser):
     group.add_option("-p", dest="", help="Ignored")
     return group
 
+def get_windows_option_group(parser):
+    group = optparse.OptionGroup(parser, "Machine Dependent Options")
+    group.add_option("-m", help="some machine dependent option",
+                     action="append", dest='m_option',
+                     default=[])
+
+    return group
+
 def _get_option_parser():
     parser = optparse.OptionParser('%prog [options] sources')
     parser.add_option('', "--quiet",
@@ -100,6 +108,9 @@ def _get_option_parser():
     parser.add_option("-L", "--library-path",
                       action="append", dest="library_paths", default=[],
                       help="directories to search for libraries")
+    parser.add_option("", "--header-only",
+                      action="store_true", dest="header_only", default=[],
+                      help="If specified, just generate a GIR for the given header files")
     parser.add_option("-n", "--namespace",
                       action="store", dest="namespace_name",
                       help=("name of namespace for this unit, also "
@@ -151,6 +162,10 @@ match the namespace prefix.""")
     group = get_preprocessor_option_group(parser)
     parser.add_option_group(group)
 
+    if os.environ.get('MSYSTEM') == 'MINGW32':
+        group = get_windows_option_group(parser)
+        parser.add_option_group(group)
+
     # Private options
     parser.add_option('', "--generate-typelib-tests",
                       action="store", dest="test_codegen", default=None,
@@ -377,7 +392,9 @@ def scanner_main(args):
     else:
         _error("Unknown format: %s" % (options.format, ))
 
-    if not (options.libraries or options.program):
+    if not (options.libraries
+            or options.program
+            or options.header_only):
         _error("Must specify --program or --library")
 
     namespace = create_namespace(options)
@@ -401,7 +418,10 @@ def scanner_main(args):
     transformer.set_annotations(blocks)
     transformer.parse(ss.get_symbols())
 
-    shlibs = create_binary(transformer, options, args)
+    if not options.header_only:
+        shlibs = create_binary(transformer, options, args)
+    else:
+        shlibs = []
 
     main = MainTransformer(transformer, blocks)
     main.transform()
